Big Tree Documentation
===================================

.. image:: https://badge.fury.io/py/bigtree.svg
   :target: https://badge.fury.io/py/bigtree
   :alt: python-version

.. image:: https://img.shields.io/pypi/pyversions/bigtree.svg
   :target: https://pypi.python.org/pypi/bigtree
   :alt: python-compatibility

.. image:: https://readthedocs.org/projects/bigtree/badge/?version=latest
    :target: https://bigtree.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://codecov.io/github/kayjan/bigtree/branch/master/graph/badge.svg?token=O5gyTsGIiw
   :target: https://codecov.io/gh/kayjan/bigtree
   :alt: code-coverage

.. image:: https://github.com/kayjan/bigtree/actions/workflows/pytest.yml/badge.svg
   :target: https://github.com/kayjan/bigtree/actions/workflows/pytest.yml
   :alt: github-workflows

.. image:: https://img.shields.io/static/v1?label=license&message=MIT&color=blue
   :alt: license

.. image:: https://img.shields.io/static/v1?label=style&message=black&color=black
   :alt: black

.. image:: https://badgen.net/badge/icon/buymeacoffee?icon=buymeacoffee&label
   :target: https://www.buymeacoffee.com/kayjan
   :alt: Buy Me a Coffee

.. toctree::
   :maxdepth: 2

   dag
   node
   tree
   utils
   workflows

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
